@@ -1,3 +1,4 @@
+#' @export
 store_new.aws_file <- function(class, file = NULL, resources = NULL) {
   aws_file_new(file = file, resources = resources)
 }
@@ -7,7 +8,7 @@ aws_file_new <- function(file = NULL, resources = NULL) {
   force(resources)
   enclass(
     environment(),
-    c("tar_aws_file", "tar_aws", "tar_store_file", "tar_store")
+    c("tar_aws_file", "tar_aws", "tar_external", "tar_store_file", "tar_store")
   )
 }
 
@@ -18,12 +19,12 @@ aws_file_new <- function(file = NULL, resources = NULL) {
 # external contributors from the open source community.
 # nocov start
 #' @export
-store_assert_format_setting.aws_file <- function(class) {
+store_produce_stage.tar_aws_file <- function(store, name, object) {
+  object
 }
 
 #' @export
-store_produce_stage.tar_aws_file <- function(store, name, object) {
-  object
+store_assert_format_setting.aws_file <- function(class) {
 }
 
 #' @export
@@ -31,8 +32,13 @@ store_read_object.tar_aws_file <- function(store) {
   path <- store$file$path
   bucket <- store_aws_bucket(path)
   key <- store_aws_key(path)
-  out <- path_scratch(pattern = basename(key))
-  aws.s3::save_object(object = key, bucket = bucket, file = out)
+  out <- path_scratch_fixed(name = basename(key))
+  aws.s3::save_object(
+    object = key,
+    bucket = bucket,
+    file = out,
+    check_region = TRUE
+  )
   out
 }
 
