@@ -1,3 +1,4 @@
+#' @export
 store_new.aws_rds <- function(class, file = NULL, resources = NULL) {
   aws_rds_new(file = file, resources = resources)
 }
@@ -7,7 +8,7 @@ aws_rds_new <- function(file = NULL, resources = NULL) {
   force(resources)
   enclass(
     environment(),
-    c("tar_aws_rds", "tar_aws", "tar_rds", "tar_store")
+    c("tar_aws_rds", "tar_aws", "tar_external", "tar_rds", "tar_store")
   )
 }
 
