@@ -27,11 +27,19 @@ store_write_path.tar_feather <- function(store, object, path) {
 }
 
 #' @export
-store_coerce_object.tar_feather <- function(store, object) {
-  assert_df(object, "target with format = \"feather\" must be a data frame.")
+store_cast_object.tar_feather <- function(store, object) {
   object
 }
 
+#' @export
+store_assert_format.tar_feather <- function(store, object, name) { # nolint
+  msg <- paste0(
+    "target ", name, " did not return a data frame. ",
+    "Target with format = \"feather\" must return data frames."
+  )
+  assert_df(object, msg)
+}
+
 #' @export
 store_get_packages.tar_feather <- function(store) {
   "arrow"
