@@ -123,7 +123,7 @@ inspection_class <- R6::R6Class(
     },
     resolve_target_status = function(vertices) {
       vertices <- vertices[order(vertices$name),, drop = FALSE] # nolint
-      status <- trn(
+      status <- if_any(
         self$outdated,
         self$produce_outdated(vertices),
         rep("dormant", nrow(vertices))
@@ -133,7 +133,7 @@ inspection_class <- R6::R6Class(
         target_get_type(pipeline_get_target(pipeline, name))
       })
       progress <- self$progress$database$read_condensed_data()
-      # TODO: remove when targets >= 0.2.0 is in production:
+      # Keep this line for legacy reasons:
       progress$progress <- gsub("running", "started", x = progress$progress)
       if (self$outdated) {
         progress <- progress[progress$progress != "built",, drop = FALSE] # nolint
@@ -147,6 +147,7 @@ inspection_class <- R6::R6Class(
       data_frame(name = vertices$name, type = type, status = status)
     },
     resolve_target_meta = function(vertices) {
+      self$meta$database$ensure_preprocessed(write = FALSE)
       meta <- map(vertices$name, function(name) {
         if (self$meta$exists_record(name)) {
           record <- self$meta$get_record(name)
@@ -154,7 +155,7 @@ inspection_class <- R6::R6Class(
             name = name,
             seconds = record$seconds,
             bytes = record$bytes,
-            branches = trn(
+            branches = if_any(
               anyNA(record$children) || identical(record$type, "stem"),
               NA_integer_,
               length(record$children)
