@@ -103,7 +103,7 @@ pipeline_targets_only_edges <- function(edges) {
 pipeline_upstream_edges <- function(pipeline, targets_only = TRUE) {
   edge_list <- map(pipeline$targets, ~target_upstream_edges(.x))
   edges <- do.call(rbind, edge_list)
-  edges <- trn(targets_only, pipeline_targets_only_edges(edges), edges)
+  edges <- if_any(targets_only, pipeline_targets_only_edges(edges), edges)
   edges <- edges %|||% data_frame(from = character(0), to = character(0))
   rownames(edges) <- NULL
   edges
@@ -237,7 +237,7 @@ pipeline_validate_conflicts <- function(pipeline) {
     ". Suppress this warning with Sys.setenv(TAR_WARN = \"false\") ",
     "in _targets.R."
   )
-  if (length(conflicts) && Sys.getenv("TAR_WARN") != "false") {
+  if (length(conflicts) && !identical(Sys.getenv("TAR_WARN"), "false")) {
     warn_validate(msg)
   }
 }
@@ -291,7 +291,7 @@ print.tar_pipeline <- function(x, ...) {
     "<pipeline with ",
     count,
     " target",
-    trn(identical(count, 1L), "", "s"),
+    if_any(identical(count, 1L), "", "s"),
     ">"
   )
   cat(msg)
