@@ -1,5 +1,6 @@
 #' @title List saved targets
 #' @export
+#' @family data
 #' @description List targets currently saved to `_targets/objects/`.
 #'   Does not include dynamic files or cloud storage.
 #' @return Character vector of targets saved to `_targets/objects/`.
@@ -19,7 +20,7 @@
 #' })
 #' }
 tar_objects <- function(names = NULL) {
-  choices <- trn(
+  choices <- if_any(
     dir.exists(path_objects_dir()),
     list.files(path_objects_dir(), all.files = TRUE, no.. = TRUE),
     character(0)
