@@ -4,6 +4,7 @@ library(proffer)
 # Should barely see target_load_deps() in the profiling data.
 # Use debug(store_read_path.tar_rds) to be sure readRDS() is not called. # nolint
 tar_script({
+  options(clustermq.scheduler = "multicore")
   list(
     tar_target(x, seq_len(1e3)),
     tar_target(y, x, pattern = map(x))
@@ -11,6 +12,20 @@ tar_script({
 })
 px <- pprof(tar_make(reporter = "summary", callr_function = NULL))
 
+# With silent reporter
+tar_destroy()
+px <- pprof(tar_make(reporter = "silent", callr_function = NULL))
+
+# With clustermq
+tar_destroy()
+px <- pprof(
+  tar_make_clustermq(workers = 8, reporter = "silent", callr_function = NULL)
+)
+
+# With future
+tar_destroy()
+px <- pprof(tar_make_future(reporter = "silent", callr_function = NULL))
+
 # Outdated targets
 px <- pprof(tar_outdated(callr_function = NULL))
 
@@ -25,21 +40,25 @@ tar_script({
 })
 px <- pprof(tar_make(reporter = "summary", callr_function = NULL))
 
-unlink("_targets.R")
-tar_destroy()
-
 # Metadata deduplication is not a bottleneck.
+tar_destroy()
 tar_script({
   list(
     tar_target(x, seq_len(1e4)),
     tar_target(y, x, pattern = map(x))
   )
 })
-px <- pprof(tar_make(reporter = "summary", callr_function = NULL))
+# Should and end start quickly:
+tar_make(reporter = "summary", callr_function = NULL)
 tar_script({
   list(
     tar_target(x, seq_len(1e4)),
     tar_target(y, 2 * x, pattern = map(x))
   )
 })
-px <- pprof(tar_make(reporter = "summary", callr_function = NULL))
+# Should and end start quickly:
+tar_make(reporter = "summary", callr_function = NULL)
+
+# Clean up.
+tar_destroy()
+unlink("_targets.R")
