@@ -11,7 +11,7 @@ tar_test("tar_deduplicate() works", {
   lines_progress <- readLines(path_progress())
   lines_progress <- c(lines_progress, rep(lines_progress[2], 4))
   writeLines(lines_progress, path_progress())
-  expect_warning(tar_deduplicate(), class = "condition_deprecate")
+  expect_warning(tar_deduplicate(), class = "tar_condition_deprecate")
   lines_meta <- readLines(path_meta())
   expect_equal(length(lines_meta), 2L)
   lines_progress <- readLines(path_progress())
