@@ -19,7 +19,7 @@ tar_test("%||NA%", {
   expect_equal(NULL %||NA% "y", NULL)
 })
 
-tar_test("trn()", {
-  expect_equal(trn(TRUE, "x", "y"), "x")
-  expect_equal(trn(FALSE, "x", "y"), "y")
+tar_test("if_any()", {
+  expect_equal(if_any(TRUE, "x", "y"), "x")
+  expect_equal(if_any(FALSE, "x", "y"), "y")
 })
